Learn R Programming

refitME (version 1.3.1)

MCEMfit_CR: Function for fitting VGAM capture-recapture (CR) model using the MCEM algorithm

Description

Function for fitting VGAM capture-recapture (CR) model using the MCEM algorithm where covariates have measurement error.

Usage

MCEMfit_CR(mod, sigma.sq.u, B = 50, epsilon = 1e-05, silent = FALSE)

Value

MCEMfit_CR returns model coefficient and population size estimates with standard errors and the effective sample size.

Arguments

mod

: a vglm/vgam object (this is the naive CR model). Make sure the first \(p\) input predictor variables in the naive model are the selected error-contaminated variables.

sigma.sq.u

: measurement error (ME) variance. A scalar if there is only one error-contaminated predictor variable, otherwise this must be stored as a vector (of ME variances) or a matrix if the ME covariance matrix is known.

B

: the number of Monte Carlo replication values (default is set to 50).

epsilon

: a set convergence threshold (default is set to 0.00001).

silent

: if TRUE, the convergence message (which tells the user if the model has converged and reports the number of iterations required) is suppressed (default is set to FALSE).

Warning

This function is still under development. Currently the function can only fit the CR model used in the manuscript. IT DOES NOT SUPPORT ALL VGAM families.

Author

Jakub Stoklosa, Wen-Han Hwang and David I. Warton.

References

Stoklosa, J., Hwang, W-H., and Warton, D.I. refitME: Measurement Error Modelling using Monte Carlo Expectation Maximization in R.

See Also

MCEMfit_glm

Examples

Run this code
# A VGAM example using the Prinia flaviventris capture-recapture data.

library(refitME)
library(VGAM)

data(Priniadata)

tau <- 17   # No. of capture occasions.
w1 <- Priniadata$w1 # Bird wing length predictor.

CR_naiv <- vglm(cbind(cap, noncap) ~ w1,
   VGAM::posbinomial(omit.constant = TRUE, parallel = TRUE ~ w1),
   data = Priniadata, trace = FALSE)

sigma.sq.u <- 0.37 # ME variance.

CR_MCEM <- refitME(CR_naiv, sigma.sq.u)

detach(package:VGAM)

Run the code above in your browser using DataLab